## v1.0.0rc1

- 修复 `reg_model` 的一处判断逻辑错误

## v1.0.0

- 为 `ReplicaionId` 新增魔法方法
- 为 `CoordOffset` 新增 `from_offset` 方法

## v1.1.0

Yanked release

## v1.1.1

- 添加基础路由类型以支持多芯片

## v1.1.2

- 修复 `bit_split` 截取高位错误的问题
